enum GraphType { HISTOGRAM };		// eventually, multiple graph types descendant from cGraph

//-- default sizes
const int MARGIN_TOP = 16;
const int MARGIN_RGT = 8;
const int MARGIN_LFT = 2;
const int MARGIN_BTM = 2;
const int XTEXT_HEIGHT = 14;
const int XLABEL_HEIGHT = 14;
const int YTEXT_WIDTH = 14;
const int YLABEL_WIDTH = 48;
const int YLABEL_HEIGHT = 14;
const int X_TICKHEIGHT = 3;
const int Y_TICKWIDTH = 2;

class CGraph : public CItem { 
	public : 
		GraphType m_iType;

		//-- Titles
		CString m_cTitle;		
		CString m_cXTitle;
		CString m_cYTitle;
		void SetTitles( const char * pchGraphTitle, const char * pchXTitle, const char * pchYTitle );

		//-- Scales
		double m_dXMin, m_dXMax;	// full scale for X
		double m_dXLabelMin;		// value at first X scale label
		double m_dXLabelSep;		// distance between labels
		double m_dXTickMin;			// value at first X scale tick mark
		double m_dXTickSep;			// distance tick marks
		double m_dYMin, m_dYMax;	// full scale for Y
		double m_dYLabelMin;		// value at first Y scale label
		double m_dYLabelSep;		// distance between labels
		double m_dYTickMin;			// value at first Y scale tick mark
		double m_dYTickSep;			// distance tick marks

		void SetXScale( double dMin, double dMax );	// set X range and reasonable label/tick mark divisions
		void SetYScale( double dMin, double dMax ); // set Y range and reasonable label/tick mark divisions
		void SetXScale( );							// default based on bins
		void SetYScale( );							// default based on loaded data 

		void DrawXLabel( HDC hdc, const char * pchLabel, double d );	
		void DrawXTick( HDC hdc, double d );
		void DrawYTitle( HDC hdc );
		void DrawYLabel( HDC hdc, const char * pchLabel, double d );
		void DrawYTick( HDC hdc, double d );

		void DrawXTitle( HDC hdc );
		void DrawXScale( HDC hdc );
		void DrawYScale( HDC hdc );
		
		//-- Graph area 
		RECT m_rctPic;			// coordinates of picture frame within device context to draw on.
		RECT m_rctData;			// area of data display within picture frame
		void SetRectangles( RECT & rctPic );
		void DrawDataFrame( HDC hdc );
		COLORREF m_crLine;		// outline color
		COLORREF m_crFill;		// fill color
		COLORREF m_crCurve;		// fit curves colors
		
		//-- 
		virtual ~CGraph() { }
		virtual void Draw( HDC hdc, RECT rctPic ) { }
		virtual void AddData( int iItems, double * aData ) { } 
		virtual double XMin() { return 0.0; }
		virtual double XMax() { return 100.0; }
		virtual double YMin() { return 0.0; }
		virtual double YMax() { return 100.0; }
	};

		
class CHistogram : public CGraph { 
	public :						//-- all public for easy access.
		int m_iBins;				// number of bins
		int m_iItems;				// number of items binned
		double m_dMin;				// Low value for bin[0]
		double m_dMax;				// Low value for bin[0]
		double m_dBinWidth;			// Width of each bin
		int * m_aiBin;				// counts of data in each block.
		//bool m_bIncludeOutOfRange;
		
	public : 
		//-- Construct from set of data or known ranges
		CHistogram( int iItems, double * aData, int iBins );
		CHistogram( int iBins, double dMin, double dBinWidth );
		
		//-- Destructor req'd for m_aiBin
		~CHistogram();

		//-- Construct empty histogram of specified ranges
		bool Create( int iBins, double dMin, double dBinWidth );
		
		//-- add data to existing histogram
		void AddDatum( double d );
		void AddData( int iItems, double * aData );

		//-- render on provided device context.		
		void Draw( HDC hdc, RECT rctPic );

		double XMin();
		double XMax();
		double YMin();
		double YMax();
	};

